@@ -1,12 +1,13 @@
 '''The Nester Module'''
 
-def print_lol(l, level=0):
+def print_lol(l, indent=False, level=0):
     '''Function that prints a given list recursively with indentation'''
     for item in l:
         if isinstance(item, list):
             print_lol(item, level+1)
         else:
-            for tab_stop in range(level):
-                print("\t",end="")
+            if indent:
+                for tab_stop in range(level):
+                    print("\t",end="")
             print(item)
         
